                                                                                                                                                                                         
import time                                                                                                                                                                                                      
import importlib                                                                                                                                                                                                 
import sys                                                                                                                                                                                                       
from typing import Dict                                                                                                                                                                                          
                                                                                                                                                                                                                
def measure_import_time(module_name: str) -> float:                                                                                                                                                              
    """Measure the time taken to import a module.                                                                                                                                                                
                                                                                                                                                                                                                
    Args:                                                                                                                                                                                                        
        module_name: Name of the module to import                                                                                                                                                                
                                                                                                                                                                                                                
    Returns:                                                                                                                                                                                                     
        Time taken in seconds                                                                                                                                                                                    
    """                                                                                                                                                                                                          
    start_time = time.time()                                                                                                                                                                                     
    importlib.import_module(module_name)                                                                                                                                                                         
    end_time = time.time()                                                                                                                                                                                       
    return end_time - start_time                                                                                                                                                                                 
                                                                                                                                                                                                                
def measure_multiple_imports(module_names: list[str]) -> Dict[str, float]:                                                                                                                                       
    """Measure import times for multiple modules.                                                                                                                                                                
                                                                                                                                                                                                                
    Args:                                                                                                                                                                                                        
        module_names: List of module names to import                                                                                                                                                             
                                                                                                                                                                                                                
    Returns:                                                                                                                                                                                                     
        Dictionary mapping module names to import times                                                                                                                                                          
    """                                                                                                                                                                                                          
    results = {}                                                                                                                                                                                                 
    for module in module_names:                                                                                                                                                                                  
        # Remove module if already imported                                                                                                                                                                      
        if module in sys.modules:                                                                                                                                                                                
            del sys.modules[module]                                                                                                                                                                              
        results[module] = measure_import_time(module)                                                                                                                                                            
    return results                                                                                                                                                                                               
                                                                                                                                                                                                                
if __name__ == "__main__":                                                                                                                                                                                       
    # Example usage                                                                                                                                                                                              
    modules_to_test = ["langchain_anthropic", "anthropic", "anthropic.types", "langchain_core"]                                                                                                                                                            
    results = measure_multiple_imports(modules_to_test)                                                                                                                                                          
                                                                                                                                                                                                                
    print("\nImport times:")                                                                                                                                                                                     
    for module, import_time in results.items():                                                                                                                                                                  
        print(f"{module}: {import_time:.4f} seconds") 
